@@ -10,14 +10,14 @@ var searchData=
   ['parseformula_7',['parseFormula',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaParser.html#ac143e53e0f362d10722414f176c9a5f3',1,'com::sun::star::sheet::XFormulaParser']]],
   ['parsepredefinedtoken_8',['parsePredefinedToken',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#ad5f1be91fbe86853200391f828d4166b',1,'com::sun::star::i18n::XCharacterClassification']]],
   ['parsesmart_9',['parseSmart',['../interfacecom_1_1sun_1_1star_1_1util_1_1XURLTransformer.html#a6db59da6454642280037ba618c116bc5',1,'com::sun::star::util::XURLTransformer']]],
-  ['parsestream_10',['parsestream',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastParser.html#a91df87cbb74a1c3266f2afc8c8c86ac7',1,'com::sun::star::xml::sax::XFastParser::parseStream()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XParser.html#aa0bcc50af6f8f48eac67567fac8581ef',1,'com::sun::star::xml::sax::XParser::parseStream()']]],
+  ['parsestream_10',['parseStream',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastParser.html#a91df87cbb74a1c3266f2afc8c8c86ac7',1,'com::sun::star::xml::sax::XFastParser::parseStream()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XParser.html#aa0bcc50af6f8f48eac67567fac8581ef',1,'com::sun::star::xml::sax::XParser::parseStream()']]],
   ['parsestrict_11',['parseStrict',['../interfacecom_1_1sun_1_1star_1_1util_1_1XURLTransformer.html#ae44affa3b35dddf8eac1ab335f3f49b2',1,'com::sun::star::util::XURLTransformer']]],
   ['parseuri_12',['parseURI',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocumentBuilder.html#a88458530f575bd3b1951b7d490e26f39',1,'com::sun::star::xml::dom::XDocumentBuilder']]],
   ['paste_13',['paste',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html#a833ef5ac09ddd022d60a3d6eb23e2eef',1,'com::sun::star::sheet::XSheetPastable']]],
   ['pastecellrange_14',['pasteCellRange',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html#a2f603786ba53fae5672bf5d9ca25f7ab',1,'com::sun::star::sheet::XSheetPastable']]],
   ['pasteformat_15',['pasteFormat',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html#af45a52f889867da4d9c17733e56d87ff',1,'com::sun::star::sheet::XSheetPastable']]],
   ['pastetext_16',['pasteText',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEditableText.html#a6c7eab81cd4c6f6a8562a7440eba704a',1,'com::sun::star::accessibility::XAccessibleEditableText']]],
-  ['pause_17',['pause',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitExperimental.html#af3711142ca5f8bc7289625326b79c8c6',1,'com::sun::star::awt::XToolkitExperimental::pause()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html#a7167f5c196fc5e167bfabde1a730e81d',1,'com::sun::star::presentation::XSlideShowController::pause()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#a17c185da1f05243edf62f7bc06204480',1,'com::sun::star::presentation::XSlideShow::pause()'],['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html#a7167f5c196fc5e167bfabde1a730e81d',1,'com::sun::star::drawing::XSlidePreviewCache::pause()']]],
+  ['pause_17',['pause',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitExperimental.html#af3711142ca5f8bc7289625326b79c8c6',1,'com::sun::star::awt::XToolkitExperimental::pause()'],['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html#a7167f5c196fc5e167bfabde1a730e81d',1,'com::sun::star::drawing::XSlidePreviewCache::pause()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#a17c185da1f05243edf62f7bc06204480',1,'com::sun::star::presentation::XSlideShow::pause()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html#a7167f5c196fc5e167bfabde1a730e81d',1,'com::sun::star::presentation::XSlideShowController::pause()']]],
   ['paused_18',['paused',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowListener.html#a8577167d93b219383049ecbb0c9bbb78',1,'com::sun::star::presentation::XSlideShowListener']]],
   ['pop_19',['pop',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a312e7f6c761a199c1369fbe651e084f0',1,'com::sun::star::awt::XGraphics::pop()'],['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XProgressHandler.html#a312e7f6c761a199c1369fbe651e084f0',1,'com::sun::star::ucb::XProgressHandler::pop()']]],
   ['position_20',['position',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af10444d3baf84c8f716653a38a6537ab',1,'com::sun::star::sdbc::XBlob::position()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1bd7c732653e9cd2d8e01873eee5aec8',1,'com::sun::star::sdbc::XClob::position()']]],
@@ -50,7 +50,7 @@ var searchData=
   ['processdictionaryevent_47',['processDictionaryEvent',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryEventListener.html#a87db7f90a37458ecaf2b063ad1f3d296',1,'com::sun::star::linguistic2::XDictionaryEventListener']]],
   ['processdictionarylistevent_48',['processDictionaryListEvent',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryListEventListener.html#adaed29383396183eb0154f5f867c1944',1,'com::sun::star::linguistic2::XDictionaryListEventListener']]],
   ['processeventstoidle_49',['processEventsToIdle',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitExperimental.html#a39eb3eb11461248b5fffa59c744d74c4',1,'com::sun::star::awt::XToolkitExperimental']]],
-  ['processinginstruction_50',['processinginstruction',['../interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XElement.html#a794963c965527014b248fc98733fc236',1,'com::sun::star::xml::input::XElement::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XRoot.html#a794963c965527014b248fc98733fc236',1,'com::sun::star::xml::input::XRoot::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDocumentHandler.html#a3ab873eb30fa3bd6983f8c42b2fe5922',1,'com::sun::star::xml::sax::XDocumentHandler::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastDocumentHandler.html#a3ab873eb30fa3bd6983f8c42b2fe5922',1,'com::sun::star::xml::sax::XFastDocumentHandler::processingInstruction()']]],
+  ['processinginstruction_50',['processingInstruction',['../interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XElement.html#a794963c965527014b248fc98733fc236',1,'com::sun::star::xml::input::XElement::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XRoot.html#a794963c965527014b248fc98733fc236',1,'com::sun::star::xml::input::XRoot::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDocumentHandler.html#a3ab873eb30fa3bd6983f8c42b2fe5922',1,'com::sun::star::xml::sax::XDocumentHandler::processingInstruction()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastDocumentHandler.html#a3ab873eb30fa3bd6983f8c42b2fe5922',1,'com::sun::star::xml::sax::XFastDocumentHandler::processingInstruction()']]],
   ['processlinguserviceevent_51',['processLinguServiceEvent',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguServiceEventListener.html#af9064332f36e1b8ce6ee61a3702de305',1,'com::sun::star::linguistic2::XLinguServiceEventListener']]],
   ['processvbaevent_52',['processVbaEvent',['../interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBAEventProcessor.html#ac5b215d0286740ef16d866499aac8def',1,'com::sun::star::script::vba::XVBAEventProcessor']]],
   ['propertieschange_53',['propertiesChange',['../interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertiesChangeListener.html#aae78391b8569c4248379f6c205f40d9c',1,'com::sun::star::beans::XPropertiesChangeListener']]],
